<div align="center">
  <img src="https://i.imgur.com/vUEEcII.png" alt="SunTzu Logo"><br>
</div>

# SunTzu: The Art of Data Science

## What is SunTzu?
**SunTzu** is a Python library created for data enthusiasts, with its main objective being to simplify the tasks of managing metadata and data manipulation. 

This library is powered by multiple libraries and improves compatibility between them, empowering them with the conversion to functions of the most tedious tasks of some libraries. 

To put it simply, this library is a robust solution for simplifying data science workflows, making the integration of various tools easier. 

Thus, individuals who are not very proficient in programming but know how to work with data can enhance their data science skills and start conducting faster and more meaningful data analysis.

## Table of Contents

- [Main Features](#main-features)
- [Where to get it](#how-to-get-it)
- [Libraries Used](#libraries-used)
- [License](#license)
- [Contributors](#contributors)
- [Credits](#credits)

## Main Features
- Inserting and Reading Metadata on netCDF and Parquet files
- Multiple functions for data cleaning
- Visualizing the usage of memory in the dataframes
- Improving the memory usage of the dataframes
- Facilitating the creation of graphs and automatically sending them to workspaces such as Slack and Telegram

## How to get it?
Currently, you can find:
 - Source code: [GitHub Repository](https://github.com/Abigor111/SunTzu)
 - Documentation: [Read the Docs](https://suntzu.readthedocs.io/en/latest/index.html)
 - Latest Versions: [PyPI](https://pypi.org/project/suntzu/#history)

To install it open your terminal with Python installed and use:
```sh
pip install suntzu
```
If you want to install a specific version use:
```sh
pip install suntzu==specific_version
```


## Libraries Used
- [pandas](https://pypi.org/project/pandas/)
- [pyarrow](https://pypi.org/project/pyarrow/)
- [xarray](https://pypi.org/project/xarray/)
- [numpy](https://pypi.org/project/numpy/)
- [jsonschema](https://pypi.org/project/jsonschema/)
- [matplotlib](https://pypi.org/project/matplotlib/)



## License
[MIT](LICENSE)

## Contributors
None yet. Why not be the first to contribute?

If you are not sure how can you contribute to SunTzu check this page: [CONTRIBUTING](CONTRIBUTING.md)
## Credits
 - This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [`audreyr/cookiecutter-pypackage`](https://github.com/audreyr/cookiecutter-pypackage) project template.
